@@ -7,11 +7,11 @@ import re
 import sys
 import tempfile
 from collections import Counter
-from curses import ascii
+from collections.abc import Generator
 from io import BytesIO
 from pathlib import Path
-from typing import Any, Generator
-from typing.io import IO
+from typing import IO, Any, cast
+
 import fsutil
 import ots
 from fontTools import unicodedata
@@ -245,14 +245,55 @@ class Font:
         {"tag": "wdth", "name": "Width"},
         {"tag": "wght", "name": "Weight"},
         # https://fonts.google.com/variablefonts#axis-definitions
+        {"tag": "ARRR", "name": "AR Retinal Resolution"},
+        {"tag": "YTAS", "name": "Ascender Height"},
+        {"tag": "BLED", "name": "Bleed"},
+        {"tag": "BNCE", "name": "Bounce"},
         {"tag": "CASL", "name": "Casual"},
+        {"tag": "CTRS", "name": "Contrast"},
+        {"tag": "XTRA", "name": "Counter Width"},
         {"tag": "CRSV", "name": "Cursive"},
+        {"tag": "YTDE", "name": "Descender Depth"},
+        {"tag": "EHLT", "name": "Edge Highlight"},
+        {"tag": "ELXP", "name": "Element Expansion"},
+        {"tag": "ELGR", "name": "Element Grid"},
+        {"tag": "ELSH", "name": "Element Shape"},
+        {"tag": "EDPT", "name": "Extrusion Depth"},
+        {"tag": "YTFI", "name": "Figure Height"},
+        # Removed: https://github.com/google/fonts/pull/2594
         {"tag": "XPRN", "name": "Expression"},
         {"tag": "FILL", "name": "Fill"},
+        {"tag": "FLAR", "name": "Flare"},
         {"tag": "GRAD", "name": "Grade"},
+        {"tag": "XELA", "name": "Horizontal Element Alignment"},
+        {"tag": "XPN1", "name": "Horizontal Position of Paint 1"},
+        {"tag": "XPN2", "name": "Horizontal Position of Paint 2"},
+        {"tag": "HEXP", "name": "Hyper Expansion"},
+        {"tag": "INFM", "name": "Informality"},
+        {"tag": "YTLC", "name": "Lowercase Height"},
         {"tag": "MONO", "name": "Monospace"},
+        {"tag": "MORF", "name": "Morph"},
+        {"tag": "XROT", "name": "Rotation in X"},
+        {"tag": "YROT", "name": "Rotation in Y"},
+        {"tag": "ZROT", "name": "Rotation in Z"},
+        {"tag": "ROND", "name": "Roundness"},
+        {"tag": "SCAN", "name": "Scanlines"},
+        {"tag": "SHLN", "name": "Shadow Length"},
+        {"tag": "SHRP", "name": "Sharpness"},
+        {"tag": "SZP1", "name": "Size of Paint 1"},
+        {"tag": "SZP2", "name": "Size of Paint 2"},
         {"tag": "SOFT", "name": "Softness"},
+        {"tag": "SPAC", "name": "Spacing"},
+        {"tag": "XOPQ", "name": "Thick Stroke"},
+        {"tag": "YOPQ", "name": "Thin Stroke"},
+        {"tag": "YTUC", "name": "Uppercase Height"},
+        {"tag": "YELA", "name": "Vertical Element Alignment"},
+        {"tag": "YEXT", "name": "Vertical Extension"},
+        {"tag": "YPN1", "name": "Vertical Position of Paint 1"},
+        {"tag": "YPN2", "name": "Vertical Position of Paint 2"},
+        {"tag": "VOLM", "name": "Volume"},
         {"tag": "WONK", "name": "Wonky"},
+        {"tag": "YEAR", "name": "Year"},
     ]
     _VARIABLE_AXES_BY_TAG: dict[str, Any] = {
         axis["tag"]: axis for axis in _VARIABLE_AXES
@@ -350,7 +391,7 @@ class Font:
 
     def __init__(
         self,
-        filepath: str | Path | IO | TTFont | Font,
+        filepath: str | Path | IO[Any] | TTFont | Font,
         **kwargs: Any,
     ) -> None:
         """
@@ -364,14 +405,14 @@ class Font:
         super().__init__()
 
         self._filepath: str | Path | None = None
-        self._fileobject: IO | None = None
+        self._fileobject: IO[Any] | None = None
         self._ttfont: TTFont | None = None
         self._kwargs: dict[str, Any] = {}
 
         if isinstance(filepath, (Path, str)):
             self._init_with_filepath(str(filepath), **kwargs)
         elif hasattr(filepath, "read"):
-            self._init_with_fileobject(filepath, **kwargs)
+            self._init_with_fileobject(cast(IO[Any], filepath), **kwargs)
         elif isinstance(filepath, Font):
             self._init_with_font(filepath, **kwargs)
         elif isinstance(filepath, TTFont):
@@ -399,7 +440,7 @@ class Font:
 
     def _init_with_fileobject(
         self,
-        fileobject: IO,
+        fileobject: IO[Any],
         **kwargs: Any,
     ) -> None:
         try:
@@ -426,6 +467,7 @@ class Font:
     ) -> None:
         self._fileobject = BytesIO()
         ttfont.save(self._fileobject)
+        self._fileobject.seek(0)
         self._ttfont = TTFont(self._fileobject, **kwargs)
         self._kwargs = kwargs
 
@@ -484,7 +526,7 @@ class Font:
         self,
         *,
         ignore_blank: bool = False,
-    ) -> Generator[dict[str, Any], None, None]:
+    ) -> Generator[dict[str, Any]]:
         """
         Gets the font characters.
 
@@ -507,7 +549,9 @@ class Font:
                 char = chr(code)
             else:
                 continue
-            if ascii.iscntrl(char):
+            # check if is control character
+            char_code = ord(char)
+            if char_code < 0x20 or char_code == 0x7F:
                 continue
             if glyfs and ignore_blank:
                 glyf = glyfs.get(char_name)
@@ -829,7 +873,7 @@ class Font:
 
     def get_glyphs(
         self,
-    ) -> Generator[dict[str, Any], None, None]:
+    ) -> Generator[dict[str, Any]]:
         """
         Gets the font glyphs and their own composition.
 
@@ -1781,8 +1825,8 @@ class Font:
 
     def save_to_fileobject(
         self,
-        fileobject: IO | None = None,
-    ) -> IO:
+        fileobject: IO[Any] | None = None,
+    ) -> IO[Any]:
         """
         Writes the font to a file-like object. If no file-object is passed, an
         instance of `BytesIO` is created for the user.
@@ -1796,6 +1840,7 @@ class Font:
         if fileobject is None:
             fileobject = BytesIO()
         font.save(fileobject)
+        fileobject.seek(0)
         return fileobject
 
     def save_variable_instances(
