@@ -1,7 +1,9 @@
 from __future__ import annotations
+
 import re
 import unicodedata
-from typing import Any, Callable
+from collections.abc import Callable
+from typing import Any
 
 import fsutil
 
